@@ -1,6 +1,8 @@
 import datetime
 import functools
 import sys
+import inspect
+import unittest
 
 from dateutil import parser
 
@@ -88,6 +90,21 @@ def date_to_fakedate(date):
                     date.day)
 
 
+class FreezeMixin(object):
+    """
+    With unittest.TestCase subclasses, we must return the class from our
+    freeze_time decorator, else test discovery tools may not discover the
+    test. Instead, we inject this mixin, which starts and stops the freezer
+    before and after each test.
+    """
+    def setUp(self):
+        self._freezer.start()
+        super(FreezeMixin, self).setUp()
+
+    def tearDown(self):
+        super(FreezeMixin, self).tearDown()
+        self._freezer.stop()
+
 class _freeze_time():
 
     def __init__(self, time_to_freeze_str, tz_offset):
@@ -97,6 +114,13 @@ class _freeze_time():
         self.tz_offset = tz_offset
 
     def __call__(self, func):
+        if inspect.isclass(func) and issubclass(func, unittest.TestCase):
+            # Inject a mixin that does what we want, as otherwise we
+            # would not be found by the test discovery tool.
+            func.__bases__ = (FreezeMixin,) + func.__bases__
+            # And, we need a reference to this object...
+            func._freezer = self
+            return func
         return self.decorate_callable(func)
 
     def __enter__(self):
@@ -117,7 +141,7 @@ class _freeze_time():
         for module in modules:
             if module is None:
                 continue
-            if module.__name__ != 'datetime':
+            if hasattr(module, "__name__") and module.__name__ != 'datetime':
                 if hasattr(module, 'datetime') and module.datetime == real_datetime:
                     module.datetime = FakeDatetime
                 if hasattr(module, 'date') and module.date == real_date:
@@ -126,7 +150,7 @@ class _freeze_time():
         datetime.datetime.time_to_freeze = self.time_to_freeze
         datetime.datetime.tz_offset = self.tz_offset
 
-        # Since datetime.datetime has already been mocket, just use that for
+        # Since datetime.datetime has already been mocked, just use that for
         # calculating the date
         datetime.date.date_to_freeze = datetime.datetime.now().date()
 
